@@ -3,9 +3,8 @@
 """Top-level package for LexicalRichness."""
 
 __title__ = 'lexicalrichness'
-__author__ = """Shen Yan Shun (Lucas)"""
 __author__ = """Lucas Shen YS"""
-__email__ = 'shen1ys@gmail.com'
-__version__ = '0.1.3'
+__email__ = 'lucas@lucasshen.com'
+__version__ = '0.3.1'
 
 from .lexicalrichness import *
